Development
--------------------

Team
~~~~~~

* `Hillary Scannell <https://www.hillaryscannell.com/>`_, Columbia / LDEO
* `Ryan Abernathey <http://rabernat.github.io/>`_, Columbia / LDEO


History
~~~~~~

The origonal inspiration behind ocetrac was the lack of tools available to track dangerous marine heatwaves as they evolved throughout the ocean. The project grew out of a collaboration with `David John Gagne <https://staff.ucar.edu/users/dgagne>`_,  `Dan Whitt <https://danielwhitt.github.io/>`_, and  `LuAnne Thompson <https://www.ocean.washington.edu/home/LuAnne+Thompson>`_ during the `NCAR ASP Graduate Visitor Program <https://asp.ucar.edu/graduate-visitors/graduate-visitor-program>`_ attended by Hillary during the spring of 2020. Ryan became involved in fall 2020 and helped refactor the code into a proper python package.  


Future 
~~~~~~

By adopting open-source best practices, we hope ocetrac will grow into a widely used, community-based project. We anticipate ocetrac will have broad applications in geoscience and are excited to see it used in other domains besides oceanography. You can get involved by trying out ocetrac, filing `issues <https://github.com/ocetrac/ocetrac/issues>`_ if you find problems, and making `pull requests <https://github.com/ocetrac/ocetrac/pulls>`_ if you make improvements.



